Learn R Programming

poseticDataAnalysis (version 1.0.0)

BubleyDyerEvaluationGenerator-class: An S4 class to represent function evaluation based on the Bubley-Dyer procedure.

Description

An S4 class to represent function evaluation based on the Bubley-Dyer procedure.

Arguments

Slots

ptr

an external pointer to a C++ data