Learn R Programming

poseticDataAnalysis (version 1.0.0)

BubleyDyerMRPGenerator: Generator of an approximated MRP matrix.

Description

Creates an object of S4 class BubleyDyerMRPGenerator for the computation of an approximated MRP matrix, starting from a set of random linear extensions, sampled according to the Bubley-Dyer procedure. Actually, this function does not compute the MRP matrix, but just the object that will compute it, by using function BubleyDyerMRP.

Usage

BubleyDyerMRPGenerator(poset = NULL, seed = NULL)

Value

An object of S4 class BubleyDyerMRPGenerator.

Arguments

poset

Object of S4 class POSet representing the poset whose MRP are computed. Argument poset must be created by using any function contained in the package aimed at building object of S4 class POSet (e.g. POSet(), LinearPOSet(), ProductPOSet(), ...) .

seed

Positive integer to initialize the random linear extension generation.

Examples

Run this code
el <- c("a", "b", "c", "d")

dom <- matrix(c(
  "a", "b",
  "c", "b",
  "b", "d"
), ncol = 2, byrow = TRUE)

pos <- POSet(elements = el, dom = dom)

BDgen <- BubleyDyerMRPGenerator(pos)

Run the code above in your browser using DataLab