LEBubleyDyer: Generator of linear extensions through the Bubley-Dyer procedure.
Description
Creates an object of S4 class LEBubleyDyer, needed to sample the linear extensions of a given poset according to the Bubley-Dyer
procedure. Actually, this function does not sample the linear extensions, but just generates the object that will sample them
by using function LEGet.
Usage
LEBubleyDyer(poset, seed = NULL)
Value
An object of class LEBubleyDyer.
Arguments
poset
An object of S4 class POSet representing the poset whose linear extensions are generated.
Argument poset must be created by using any function contained in the package aimed at building object of S4 class POSet
(e.g. POSet(), LinearPOSet(), ProductPOSet(), ...) .
seed
Positive integer to initialize the random linear extension generation.